aboutsummaryrefslogtreecommitdiff
path: root/include/clang/Lex/MacroInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/clang/Lex/MacroInfo.h')
-rw-r--r--include/clang/Lex/MacroInfo.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/clang/Lex/MacroInfo.h b/include/clang/Lex/MacroInfo.h
index 009ec20f41..90f95b7ace 100644
--- a/include/clang/Lex/MacroInfo.h
+++ b/include/clang/Lex/MacroInfo.h
@@ -62,8 +62,8 @@ class MacroInfo {
/// it has not yet been redefined or undefined.
bool IsBuiltinMacro : 1;
- /// IsFromPCH - True if this macro was loaded from a PCH file.
- bool IsFromPCH : 1;
+ /// IsFromAST - True if this macro was loaded from an AST file.
+ bool IsFromAST : 1;
private:
//===--------------------------------------------------------------------===//
@@ -185,11 +185,11 @@ public:
/// __LINE__, which requires processing before expansion.
bool isBuiltinMacro() const { return IsBuiltinMacro; }
- /// isFromPCH - Return true if this macro was loaded from a PCH file.
- bool isFromPCH() const { return IsFromPCH; }
+ /// isFromAST - Return true if this macro was loaded from an AST file.
+ bool isFromAST() const { return IsFromAST; }
- /// setIsFromPCH - Set whether this macro was loaded from a PCH file.
- void setIsFromPCH(bool FromPCH = true) { IsFromPCH = FromPCH; }
+ /// setIsFromAST - Set whether this macro was loaded from an AST file.
+ void setIsFromAST(bool FromAST = true) { IsFromAST = FromAST; }
/// isUsed - Return false if this macro is defined in the main file and has
/// not yet been used.